Class: Blacklight::Component
- Inherits:
-
ViewComponent::Base
- Object
- ViewComponent::Base
- Blacklight::Component
- Defined in:
- lib/blacklight/component.rb
Direct Known Subclasses
ConstraintComponent, ConstraintLayoutComponent, ConstraintsComponent, Document::ActionComponent, Document::ActionsComponent, Document::BookmarkComponent, Document::CitationComponent, Document::GroupComponent, Document::MoreLikeThisComponent, Document::PageHeaderComponent, Document::ShowToolsComponent, Document::SidebarComponent, Document::ThumbnailComponent, DocumentComponent, DocumentMetadataComponent, DocumentTitleComponent, FacetFieldPaginationComponent, FacetItemPivotComponent, Facets::CheckboxesComponent, Facets::CountComponent, Facets::FieldComponent, Facets::FiltersComponent, Facets::InclusiveConstraintComponent, Facets::IndexNavigationComponent, Facets::ItemComponent, Facets::ListComponent, Facets::NoLayoutComponent, Facets::SelectedValueComponent, Facets::SuggestComponent, HeaderComponent, HiddenSearchStateComponent, MetadataFieldComponent, MetadataFieldLayoutComponent, Response::FacetGroupComponent, Response::FacetToggleButtonComponent, Response::PaginationComponent, Response::SortComponent, Response::SpellcheckComponent, Response::ViewTypeButtonComponent, Response::ViewTypeComponent, Search::PerPageComponent, Search::SidebarComponent, SearchBarComponent, SearchButtonComponent, SearchContext::ServerAppliedParamsComponent, SearchContext::ServerItemPaginationComponent, SearchHeaderComponent, SearchNavbarComponent, SkipLinkComponent, SkipLinkItemComponent, StartOverButtonComponent, System::DropdownButtonComponent, System::DropdownComponent, System::FlashMessageComponent, System::ModalComponent, ThemeSwitcherComponent, TopNavbarComponent
Class Method Summary collapse
- .reset_compiler! ⇒ Object
-
.sidecar_files(*args, **kwargs) ⇒ Object
This allows the host application to provide erb templates that override the templates provided by Blacklight.
- .upstream_sidecar_files ⇒ Object
Class Method Details
.reset_compiler! ⇒ Object
10 11 12 |
# File 'lib/blacklight/component.rb', line 10 def reset_compiler! @__vc_compiler = nil end |
.sidecar_files(*args, **kwargs) ⇒ Object
This allows the host application to provide erb templates that override the templates provided by Blacklight.
16 17 18 19 20 21 22 23 24 25 26 27 28 |
# File 'lib/blacklight/component.rb', line 16 def sidecar_files(*args, **kwargs) upstream_sidecar_files(*args, **kwargs).map do |path| components_path = config.generate.path app_path = Rails.root.join(path.slice(path.index(components_path)..-1).to_s).to_s if File.exist?(app_path) app_path else path end end end |
.upstream_sidecar_files ⇒ Object
8 |
# File 'lib/blacklight/component.rb', line 8 alias upstream_sidecar_files sidecar_files |