Class: Blacklight::Configuration::ViewConfig::Index
- Inherits:
-
Blacklight::Configuration::ViewConfig
- Object
- OpenStruct
- OpenStructWithHashAccess
- Blacklight::Configuration::ViewConfig
- Blacklight::Configuration::ViewConfig::Index
- Defined in:
- lib/blacklight/configuration/view_config.rb
Instance Attribute Summary collapse
- #collection_actions ⇒ String, Symbol
-
#group ⇒ false, ...
What field, if any, to use to render grouped results.
-
#respond_to ⇒ OpenStructWithHashAccess{Symbol => OpenStruct}
Additional response formats for search results; see Blacklight::Catalog#additional_response_formats for information about the OpenStruct data.
Attributes inherited from Blacklight::Configuration::ViewConfig
#display_type_field, #document_actions, #document_component, #icon, #partials, #template, #title_field
Instance Method Summary collapse
Methods inherited from Blacklight::Configuration::ViewConfig
#display_label, #search_bar_presenter_class
Methods inherited from OpenStructWithHashAccess
#deep_dup, #merge, #merge!, #reverse_merge, #select, #sort_by, #sort_by!, #try
Instance Attribute Details
#collection_actions ⇒ String, Symbol
63 64 65 |
# File 'lib/blacklight/configuration/view_config.rb', line 63 def document_presenter_class super || Blacklight::IndexPresenter end |
#group ⇒ false, ...
Returns what field, if any, to use to render grouped results.
63 64 65 |
# File 'lib/blacklight/configuration/view_config.rb', line 63 def document_presenter_class super || Blacklight::IndexPresenter end |
#respond_to ⇒ OpenStructWithHashAccess{Symbol => OpenStruct}
Returns additional response formats for search results; see Blacklight::Catalog#additional_response_formats for information about the OpenStruct data.
63 64 65 |
# File 'lib/blacklight/configuration/view_config.rb', line 63 def document_presenter_class super || Blacklight::IndexPresenter end |
Instance Method Details
#document_presenter_class ⇒ Object
63 64 65 |
# File 'lib/blacklight/configuration/view_config.rb', line 63 def document_presenter_class super || Blacklight::IndexPresenter end |
#to_h ⇒ Object
67 68 69 |
# File 'lib/blacklight/configuration/view_config.rb', line 67 def to_h super.merge(document_presenter_class: document_presenter_class) end |