Module: Blacklight::Document::SemanticFields::ClassMethods

Defined in:
app/models/concerns/blacklight/document/semantic_fields.rb

Instance Method Summary collapse

Instance Method Details

#field_semanticsObject

Class-level method for accessing/setting semantic mappings for solr stored fields. Can be set by local app, key is a symbol for a semantic, value is a solr stored field.

Stored field can be single or multi-value. In some cases clients may only use the first value from a multi-value field.

Currently documented semantic tokens, not all may be used by core BL, but some may be used by plugins present or future. :title, :author, :year, :language => User-presentable strings.



22
23
24
# File 'app/models/concerns/blacklight/document/semantic_fields.rb', line 22

def field_semantics
  @field_semantics ||= {}
end