Module: Blacklight::Document::Sms
- Defined in:
- app/models/concerns/blacklight/document/sms.rb
Overview
This module provides the body of an email export based on the document's semantic values
Instance Method Summary collapse
-
#to_sms_text(config = nil) ⇒ Object
Return a text string that will be the body of the email.
Instance Method Details
#to_sms_text(config = nil) ⇒ Object
Return a text string that will be the body of the email
6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 |
# File 'app/models/concerns/blacklight/document/sms.rb', line 6 def to_sms_text(config = nil) body = [] if config body = config.sms_fields.map do |name, field| values = [self[name]].flatten "#{field.label} #{values.first}" if self[name].present? end end # Use to_semantic_values for backwards compatibility if body.empty? semantics = to_semantic_values body << I18n.t('blacklight.sms.text.title', value: semantics[:title].first) if semantics[:title].present? body << I18n.t('blacklight.sms.text.author', value: semantics[:author].first) if semantics[:author].present? end return body.join unless body.empty? end |