Class: Blacklight::FacetCheckboxItemPresenter
- Inherits:
-
FacetItemPresenter
- Object
- FacetItemPresenter
- Blacklight::FacetCheckboxItemPresenter
- Defined in:
- app/presenters/blacklight/facet_checkbox_item_presenter.rb
Instance Method Summary collapse
-
#selected? ⇒ Boolean
Check if the query parameters have any inclusive facets with the given value.
Instance Method Details
#selected? ⇒ Boolean
Check if the query parameters have any inclusive facets with the given value
7 8 9 |
# File 'app/presenters/blacklight/facet_checkbox_item_presenter.rb', line 7 def selected? search_state.filter(facet_config).values(except: [:filters, :missing]).flatten.include?(value) end |