Module: Blacklight::SearchContext::ClassMethods
- Defined in:
- app/controllers/concerns/blacklight/search_context.rb
Instance Method Summary collapse
-
#record_search_parameters(opts = { only: :index}) ⇒ Object
Save the submitted search parameters in the search session.
Instance Method Details
#record_search_parameters(opts = { only: :index}) ⇒ Object
Save the submitted search parameters in the search session
15 16 17 |
# File 'app/controllers/concerns/blacklight/search_context.rb', line 15 def record_search_parameters opts = { only: :index} before_action :set_current_search_session, opts end |