Exception: Blacklight::Exceptions::InvalidSolrID
- Inherits:
-
RuntimeError
- Object
- RuntimeError
- Blacklight::Exceptions::InvalidSolrID
- Defined in:
- lib/blacklight/exceptions.rb
Overview
When a request for a single solr document by id is not successful, we can raise this exception. Deprecated; this will be removed in Blacklight 6.0: