Module: Blacklight::HashAsHiddenFieldsHelperBehavior
- Included in:
- HashAsHiddenFieldsHelper
- Defined in:
- app/helpers/blacklight/hash_as_hidden_fields_helper_behavior.rb
Overview
Rails Helper methods to take a hash and turn it to form <input type=“hidden”> fields, works with hash nested with other hashes and arrays, standard rails serialization style. Oddly while Hash#to_query will do this for a URL query parameters, there seems to be no built in way to do it to create hidden form fields instead.
Code taken from marklunds.com/articles/one/314
This is used to serialize a complete current query from current params to form fields used for sort and change per-page
Instance Method Summary collapse
- #flat_hash_key(names) ⇒ Object protected
- #flatten_hash(hash = params, ancestor_names = []) ⇒ Object protected
-
#render_hash_as_hidden_fields(hash) ⇒ String
Writes out zero or more <input type=“hidden”> elements, completely representing a hash passed in using Rails-style request parameters for hashes nested with arrays and other hashes.
Instance Method Details
#flat_hash_key(names) ⇒ Object (protected)
51 52 53 54 55 56 57 58 |
# File 'app/helpers/blacklight/hash_as_hidden_fields_helper_behavior.rb', line 51 def flat_hash_key(names) names = Array.new(names) name = names.shift.to_s.dup names.each do |n| name << "[#{n}]" end name end |
#flatten_hash(hash = params, ancestor_names = []) ⇒ Object (protected)
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'app/helpers/blacklight/hash_as_hidden_fields_helper_behavior.rb', line 34 def flatten_hash(hash = params, ancestor_names = []) flat_hash = {} hash.each do |k, v| names = Array.new(ancestor_names) names << k if v.is_a?(Hash) flat_hash.merge!(flatten_hash(v, names)) else key = flat_hash_key(names) key += "[]" if v.is_a?(Array) flat_hash[key] = v end end flat_hash end |
#render_hash_as_hidden_fields(hash) ⇒ String
Writes out zero or more <input type=“hidden”> elements, completely representing a hash passed in using Rails-style request parameters for hashes nested with arrays and other hashes.
19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'app/helpers/blacklight/hash_as_hidden_fields_helper_behavior.rb', line 19 def render_hash_as_hidden_fields(hash) hidden_fields = [] flatten_hash(hash).each do |name, value| value = Array.wrap(value) value.each do |v| hidden_fields << hidden_field_tag(name, v.to_s, :id => nil) end end safe_join(hidden_fields, "\n") end |